<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// S
	'stats_description' => 'Statistics of SPIP',
	'stats_nom' => 'Statistics',
	'stats_slogan' => 'Statistics management in SPIP',
];
